@@ -6,7 +6,7 @@ func(redis-response) -> formatted result(str)
 """
 import logging
 import time
-from distutils.version import StrictVersion
+from packaging.version import parse as version_parse
 
 from prompt_toolkit.formatted_text import FormattedText
 
@@ -74,8 +74,8 @@ class OutputRender:
         utf-8 decoded.
         """
         decoded = nativestr(value)
-        splitted = "\n".join(decoded.splitlines())  # get rid of last newline
-        return splitted
+        split = "\n".join(decoded.splitlines())  # get rid of last newline
+        return split
 
     @staticmethod
     def render_nested_pair(value):
@@ -163,7 +163,7 @@ class OutputRender:
     def render_simple_string(text):
         """
         If response is b'OK', render simple string always with success color.
-        If Error happend, error will be rendered by ``render_error``
+        If Error happens, error will be rendered by ``render_error``
         """
         if text is None:
             return NIL
@@ -174,7 +174,7 @@ class OutputRender:
     def render_help(raw):
         """
         render help text message.
-        the comand like ``ACL HELP`` and ``MEMORY HELP``
+        the command like ``ACL HELP`` and ``MEMORY HELP``
         will return a list of strings.
         we render it as plain text
         """
@@ -260,7 +260,7 @@ class OutputRender:
     @staticmethod
     def render_slowlog(raw):
         fields = ["Slow log id", "Start at", "Running time(ms)", "Command"]
-        if StrictVersion(config.version) > StrictVersion("4.0"):
+        if version_parse(config.version) > version_parse("4.0"):
             fields.extend(["Client IP and port", "Client name"])
 
         rendered = []
