@@ -1,3 +1,4 @@
+import os
 import re
 import pytest
 import redis
@@ -11,6 +12,7 @@ from iredis.config import config, load_config_files
 from iredis.completers import IRedisCompleter
 from iredis.entry import Rainbow, prompt_message
 from iredis.exceptions import NotSupport
+from iredis.commands import command2syntax
 from ..helpers import formatted_text_rematch
 
 
@@ -19,6 +21,11 @@ def completer():
     return IRedisCompleter()
 
 
+zset_type = "ziplist"
+if os.environ["REDIS_VERSION"] == "7":
+    zset_type = "listpack"
+
+
 @pytest.mark.parametrize(
     "_input, command_name, expect_args",
     [
@@ -32,7 +39,7 @@ def test_send_command(_input, command_name, expect_args):
     client = Client("127.0.0.1", "6379", None)
     client.execute = MagicMock()
     next(client.send_command(_input, None))
-    args, kwargs = client.execute.call_args
+    args, _ = client.execute.call_args
     assert args == (command_name, *expect_args)
 
 
@@ -68,10 +75,10 @@ def test_do_help(config):
     client = Client("127.0.0.1", "6379", None)
     config.version = "5.0.0"
     resp = client.do_help("SET")
-    assert resp[10] == ("", "1.0.0 (Avaiable on your redis-server: 5.0.0)")
+    assert resp[10] == ("", "1.0.0 (Available on your redis-server: 5.0.0)")
     config.version = "2.0.0"
     resp = client.do_help("cluster", "addslots")
-    assert resp[10] == ("", "3.0.0 (Not avaiable on your redis-server: 2.0.0)")
+    assert resp[10] == ("", "3.0.0 (Not available on your redis-server: 2.0.0)")
 
 
 def test_rainbow_iterator():
@@ -168,7 +175,16 @@ def test_not_retry_on_authentication_error(iredis_client, config):
         iredis_client.execute("None", "GET", ["foo"])
 
 
-@pytest.mark.skipif("int(os.environ['REDIS_VERSION']) < 6")
+@pytest.mark.skipif(
+    "int(os.environ['REDIS_VERSION']) != 6",
+    reason="""
+in redis7, it will not work if you:
+1. connect redis without password
+2. set a password
+3. auth
+
+the auth will fail""",
+)
 def test_auto_select_db_and_auth_for_reconnect_only_6(iredis_client, config):
     config.retry_times = 2
     config.raw = True
@@ -255,6 +271,13 @@ def test_peek_key_not_exist(iredis_client, clean_redis, config):
     assert peek_result == ["non-exist-key doesn't exist."]
 
 
+def test_iredis_with_username():
+    with patch("redis.connection.Connection.connect"):
+        c = Client("127.0.0.1", "6379", username="abc", password="abc1")
+        assert c.connection.username == "abc"
+        assert c.connection.password == "abc1"
+
+
 def test_peek_string(iredis_client, clean_redis):
     clean_redis.set("foo", "bar")
     peek_result = list(iredis_client.do_peek("foo"))
@@ -336,12 +359,13 @@ def test_peek_zset_fetch_all(iredis_client, clean_redis):
         "myzset", dict(zip([f"hello-{index}" for index in range(3)], range(3)))
     )
     peek_result = list(iredis_client.do_peek("myzset"))
+
     formatted_text_rematch(
         peek_result[0][0:9],
         FormattedText(
             [
                 ("class:dockey", "key: "),
-                ("", r"zset \(ziplist\)  mem: \d+ bytes, ttl: -1"),
+                ("", rf"zset \({zset_type}\)  mem: \d+ bytes, ttl: -1"),
                 ("", "\n"),
                 ("class:dockey", "zcount: "),
                 ("", "3"),
@@ -364,7 +388,7 @@ def test_peek_zset_fetch_part(iredis_client, clean_redis):
         FormattedText(
             [
                 ("class:dockey", "key: "),
-                ("", r"zset \(ziplist\)  mem: \d+ bytes, ttl: -1"),
+                ("", rf"zset \({zset_type}\)  mem: \d+ bytes, ttl: -1"),
                 ("", "\n"),
                 ("class:dockey", "zcount: "),
                 ("", "40"),
@@ -508,3 +532,71 @@ def test_reissue_command_on_redis_cluster_with_password_in_dsn(
         print(call_args)
         assert list(call_args[1:]) == ["set", "foo", "bar"]
         assert call_args[0].password == "bar"
+
+
+def test_version_parse_for_auth(iredis_client):
+    """
+    fix: https://github.com/laixintao/iredis/issues/418
+    """
+    iredis_client.auth_compat("6.1.0")
+    assert command2syntax["AUTH"] == "command_usernamex_password"
+    iredis_client.auth_compat("5.0")
+    assert command2syntax["AUTH"] == "command_password"
+    iredis_client.auth_compat("5.0.14.1")
+    assert command2syntax["AUTH"] == "command_password"
+
+
+@pytest.mark.parametrize(
+    "info, version",
+    [
+        (
+            "# Server\r\nredis_version:df--128-NOTFOUND\r\n"
+            "redis_mode:standalone\r\narch_bits:64",
+            "df--128-NOTFOUND",
+        ),
+        (
+            "# Server\r\nredis_version:6.2.5\r\n"
+            "redis_git_sha1:00000000\r\n"
+            "redis_git_dirty:0\r\n"
+            "redis_build_id:915e5480613bc9b6\r\n"
+            "redis_mode:standalone ",
+            "6.2.5",
+        ),
+        (
+            "# Server\r\nredis_version:5.0.14.1\r\n"
+            "redis_git_sha1:00000000\r\nredis_git_dirty:0\r\n"
+            "redis_build_id:915e5480613bc9b6\r\n"
+            "redis_mode:standalone ",
+            "5.0.14.1",
+        ),
+    ],
+)
+def test_version_path(info, version):
+    with patch("iredis.client.config") as mock_config:
+        mock_config.no_info = True
+        mock_config.pager = "less"
+        mock_config.version = "5.0.0"
+        with patch("iredis.client.Client.execute") as mock_execute:
+            mock_execute.return_value = info
+            client = Client("127.0.0.1", "6379", None)
+            client.get_server_info()
+            assert mock_config.version == version
+
+
+def test_prompt():
+    c = Client()
+    assert str(c) == "127.0.0.1:6379> "
+
+    c = Client(prompt="{host} {port} {db}")
+    assert str(c) == "127.0.0.1 6379 0"
+
+    c = Client(prompt="{host} {port} {db} {username}")
+    assert str(c) == "127.0.0.1 6379 0 None"
+
+    c = Client(prompt="{host} {port} {db} {username}", username="foo1")
+    assert str(c) == "127.0.0.1 6379 0 foo1"
+
+    c = Client(prompt="{client_id} aabc")
+    assert re.match(r"^\d+ aabc$", str(c))
+    c = Client(prompt="{client_addr} >")
+    assert re.match(r"^127.0.0.1:\d+ >$", str(c))
